Definition
==========

Classes
-------

.. currentmodule:: ansys.edb.core

.. autosummary::
   :toctree: _autosummary

   definition.bondwire_def.ApdBondwireDef
   definition.bondwire_def.BondwireDef
   definition.component_def.ComponentDef
   definition.component_model.ComponentModel
   definition.component_pin.ComponentPin
   definition.dataset_def.DatasetDef
   definition.debye_model.DebyeModel
   definition.die_property.DieProperty
   definition.dielectric_material_model.DielectricMaterialModel
   definition.djordjecvic_sarkar_model.DjordjecvicSarkarModel
   definition.component_model.DynamicLinkComponentModel
   definition.bondwire_def.Jedec4BondwireDef
   definition.bondwire_def.Jedec5BondwireDef
   definition.material_def.MaterialDef
   definition.material_property_thermal_modifier.MaterialPropertyThermalModifier
   definition.multipole_debye_model.MultipoleDebyeModel
   definition.component_model.NPortComponentModel
   definition.package_def.PackageDef
   definition.padstack_def.PadstackDef
   definition.padstack_def_data.PadstackDefData
   definition.solder_ball_property.SolderBallProperty
   definition.component_property.ComponentProperty
   definition.ic_component_property.ICComponentProperty
   definition.io_component_property.IOComponentProperty
   definition.rlc_component_property.RLCComponentProperty
   definition.port_property.PortProperty


Enums
-----

.. autosummary::
   :toctree: _autosummary

   edb_defs.DefinitionObjType
   definition.bondwire_def.BondwireDefType
   definition.material_def.MaterialProperty
   definition.padstack_def_data.PadType
   definition.padstack_def_data.PadGeometryType
   definition.padstack_def_data.PadstackHoleRange
   definition.padstack_def_data.SolderballShape
   definition.padstack_def_data.SolderballPlacement
   definition.padstack_def_data.ConnectionPtDirection
   definition.die_property.DieType
   definition.die_property.DieOrientation
   definition.dielectric_material_model.DielectricMaterialModelType
   definition.component_model.ComponentModelType
